==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPaneDragOverEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneDragOverEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragOverEventArgsDetailDescription, _super);
    function WebPaneDragOverEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.f = null;
        _this.j = null;
        _this.m = false;
        return _this;
    }
    WebPaneDragOverEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneDragOverEventArgsDetail";
    };
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("SourcePane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Panes");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "action", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("Action");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "isValid", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("IsValid");
        },
        enumerable: true,
        configurable: true
    });
    WebPaneDragOverEventArgsDetailDescription.$t = markType(WebPaneDragOverEventArgsDetailDescription, 'WebPaneDragOverEventArgsDetailDescription', Description.$);
    WebPaneDragOverEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragOverEventArgsDetailDescription.__marshalByValueAlias = "PaneDragOverEventArgsDetail";
    return WebPaneDragOverEventArgsDetailDescription;
}(Description));
export { WebPaneDragOverEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPaneDragOverEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneDragOverEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragOverEventArgsDetailDescription, _super);
    function WebPaneDragOverEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.h = null;
        _this.l = null;
        _this.o = false;
        return _this;
    }
    WebPaneDragOverEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneDragOverEventArgsDetail";
    };
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("SourcePane");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Panes");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "action", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("Action");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragOverEventArgsDetailDescription.prototype, "isValid", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.g("IsValid");
        },
        enumerable: false,
        configurable: true
    });
    WebPaneDragOverEventArgsDetailDescription.$t = markType(WebPaneDragOverEventArgsDetailDescription, 'WebPaneDragOverEventArgsDetailDescription', Description.$);
    WebPaneDragOverEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragOverEventArgsDetailDescription.__marshalByValueAlias = "PaneDragOverEventArgsDetail";
    return WebPaneDragOverEventArgsDetailDescription;
}(Description));
export { WebPaneDragOverEventArgsDetailDescription };
